/*Market Risk Example*/

libname RDExamp "C:\users\sasdemo\RD_Examples";
%let test_env = marketrisk;

/*------------------------------------------------*/
/*---- 1. Create the environment -----------------*/
/*------------------------------------------------*/

proc risk;
  env new=RDExamp.&test_env;
  env save;
run;

/*------------------------------------------------*/
/*---- 2. Register portfolio data ----------------*/
/*------------------------------------------------*/

data RDExamp.instdata;
  input insttype $12. instid $8. holding;
  datalines;
TechCompany instid1 1000000
BankCompany instid2 1000000
;

proc risk;
  env open=RDExamp.&test_env;
  instdata Instruments file=RDExamp.instdata format=simple;
  env save;
run;

/*------------------------------------------------*/
/*---- 3. Register the market data ---------------*/
/*------------------------------------------------*/

data RDExamp.mktdata;
  TEC=15; 
  BNK=30;  
run;

data RDExamp.covdata;
	length _name_ _type_ $8;
	_type_ = "COV";
	input _name_ $ TEC BNK;  
	datalines;
TEC      .0004   .00006
BNK      .00006   .0001
;

proc risk;
	env open=RDExamp.&test_env;
	declare riskfactors=(TEC num var, BNK num var);
	marketdata Market file=RDExamp.mktdata  type=current;
	marketdata Cov    file=RDExamp.covdata  type=covariance;
	env save;
run;

/*------------------------------------------------*/
/*---- 4. Define valuation methods ---------------*/
/*------------------------------------------------*/

proc compile env=RDExamp.&test_env outlib=RDExamp.&test_env;
  method Tech_Price kind=price;
    _value_ = TEC;
  endmethod;
  method Bank_Price kind=price;
    _value_ = BNK;
  endmethod;
run;

proc risk;
  env open=RDExamp.&test_env;
  instrument TechCompany methods=(Price Tech_Price) variables = (holding);
  instrument BankCompany methods=(Price Bank_Price) variables = (holding);
  env save;
run;

/*------------------------------------------------*/
/*---- 5. Create Project and Specify Analysis ----*/
/*------------------------------------------------*/

proc risk;
  env open=RDExamp.&test_env;
  sources InstDataSource (Instruments);
  read sources=InstDataSource out=Portfolio;
  crossclass MarketRiskCC (Insttype);
  simulation Covariance method=covariance
          ndraws=50000
          outvars=(pl)
          data=Cov;
  project Project
    	    analysis=(Covariance)
          portfolio=Portfolio
          crossclass=MarketRiskCC
          data=( Market );
  env save;
run;

/*------------------------------------------------*/
/*---- 6. Run Analysis ---------------------------*/
/*------------------------------------------------*/

proc risk;
  env open=RDExamp.&test_env;
  runproject Project
    out= MarketOut
    options=(outall);
  env save;
run;
